@@ -13,15 +13,17 @@ import aws_cdk.aws_ec2._jsii
 import aws_cdk.aws_iam._jsii
 import aws_cdk.aws_kms._jsii
 import aws_cdk.aws_lambda._jsii
+import aws_cdk.aws_lambda_nodejs._jsii
 import aws_cdk.aws_ssm._jsii
 import aws_cdk.core._jsii
 import aws_cdk.custom_resources._jsii
 import aws_cdk.lambda_layer_awscli._jsii
 import aws_cdk.lambda_layer_kubectl._jsii
+import aws_cdk.lambda_layer_node_proxy_agent._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "@aws-cdk/aws-eks", "1.125.0", __name__[0:-6], "aws-eks@1.125.0.jsii.tgz"
+    "@aws-cdk/aws-eks", "1.126.0", __name__[0:-6], "aws-eks@1.126.0.jsii.tgz"
 )
 
 __all__ = [
